@@ -13,15 +13,18 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six import add_metaclass
 from spinn_utilities.abstract_base import (
     AbstractBase, abstractmethod)
 
 
-@add_metaclass(AbstractBase)
-class AbstractCanReset(object):
+class AbstractCanReset(object, metaclass=AbstractBase):
     """ Indicates an object that can be reset to time 0.
+
+    This is used when AbstractSpinnakerBase.reset is called.
+    All Vertices and all edges in the original graph
+    (the one added to by the user) will be checked and reset.
     """
+    __slots__ = []
 
     @abstractmethod
     def reset_to_first_timestep(self):
