@@ -13,12 +13,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six import add_metaclass
 from spinn_utilities.abstract_base import AbstractBase, abstractmethod
+from spinn_utilities.require_subclass import require_subclass
+from pacman.model.graphs.machine import MachineVertex
 
 
-@add_metaclass(AbstractBase)
-class AbstractHasAssociatedBinary(object):
+@require_subclass(MachineVertex)
+class AbstractHasAssociatedBinary(object, metaclass=AbstractBase):
     """ Marks a machine graph vertex that can be launched on a SpiNNaker core.
     """
 
