@@ -13,12 +13,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six import add_metaclass
 from spinn_utilities.abstract_base import AbstractBase, abstractmethod
 
 
-@add_metaclass(AbstractBase)
-class AbstractMachineAllocationController(object):
+class AbstractMachineAllocationController(object, metaclass=AbstractBase):
     """ An object that controls the allocation of a machine
     """
 
@@ -26,15 +24,25 @@ class AbstractMachineAllocationController(object):
 
     @abstractmethod
     def extend_allocation(self, new_total_run_time):
-        """ Extend the allocation of the machine from the original\
-            run time.
+        """ Extend the allocation of the machine from the original run time.
 
-        :param new_total_run_time: The total run time that is now required\
-            starting from when the machine was first allocated
-        :type new_total_run_time: float
+        :param float new_total_run_time:
+            The total run time that is now required starting from when the
+            machine was first allocated
         """
 
     @abstractmethod
     def close(self):
         """ Indicate that the use of the machine is complete.
         """
+
+    @abstractmethod
+    def where_is_machine(self, chip_x, chip_y):
+        """ Locates and returns cabinet, frame, board for a given chip in a\
+            machine allocated to this job.
+
+        :param int chip_x: chip x location
+        :param int chip_y: chip y location
+        :return: (cabinet, frame, board)
+        :rtype: tuple(int,int,int)
+        """
