@@ -13,12 +13,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six import add_metaclass
 from spinn_utilities.abstract_base import AbstractBase, abstractproperty
+from spinn_utilities.require_subclass import require_subclass
+from pacman.model.graphs.machine import MachineVertex
 
 
-@add_metaclass(AbstractBase)
-class AbstractSupportsDatabaseInjection(object):
+@require_subclass(MachineVertex)
+class AbstractSupportsDatabaseInjection(object, metaclass=AbstractBase):
     """ Marks a machine vertex as supporting injection of information via a\
         database running on the controlling host.
     """
