@@ -16,6 +16,7 @@
 from .machine_allocation_controller import MachineAllocationController
 from .machine_data_specable_vertex import MachineDataSpecableVertex
 from .provides_key_to_atom_mapping_impl import ProvidesKeyToAtomMappingImpl
+from .tdma_aware_application_vertex import TDMAAwareApplicationVertex
 
 __all__ = ["MachineAllocationController", "MachineDataSpecableVertex",
-           "ProvidesKeyToAtomMappingImpl"]
+           "ProvidesKeyToAtomMappingImpl", "TDMAAwareApplicationVertex"]
