@@ -17,10 +17,7 @@ from .abstract_database import AbstractDatabase
 from .buffered_receiving_data import BufferedReceivingData
 from .buffered_sending_region import BufferedSendingRegion
 from .buffers_sent_deque import BuffersSentDeque
-from .channel_buffer_state import ChannelBufferState
-from .end_buffering_state import EndBufferingState
 from .sqllite_database import SqlLiteDatabase
 
 __all__ = ["AbstractDatabase", "BufferedReceivingData",
-           "BufferedSendingRegion", "BuffersSentDeque", "ChannelBufferState",
-           "EndBufferingState", "SqlLiteDatabase"]
+           "BufferedSendingRegion", "BuffersSentDeque", "SqlLiteDatabase"]
