@@ -33,20 +33,15 @@ CONFIG_FILE = "spinnaker.cfg"
 FINISHED_FILENAME = "finished"
 REPORTS_DIRNAME = "reports"
 TIMESTAMP_FILENAME = "time_stamp"
+WARNING_LOGS_FILENAME = "warning_logs.txt"
 
 
 class ConfigHandler(object):
-    """
-    Subclass of AbstractSpinnaker base that handles function only dependent
-    of the config and the order its methods are called
+    """ Superclass of AbstractSpinnakerBase that handles function only \
+        dependent of the config and the order its methods are called.
     """
 
     __slots__ = [
-        #
-        "_app_data_runtime_folder",
-
-        #
-        "_app_data_top_simulation_folder",
 
         # the interface to the cfg files. supports get get_int etc
         "_config",
@@ -80,6 +75,18 @@ class ConfigHandler(object):
     ]
 
     def __init__(self, configfile, default_config_paths, validation_cfg):
+        """
+        :param str configfile:
+            The base name of the configuration file(s).
+            Should not include any path components.
+        :param list(str) default_config_paths:
+            The list of files to get default configurations from.
+        :type default_config_paths: list(str) or None
+        :param validation_cfg:
+            The list of files to read a validation configuration from.
+            If None, no such validation is performed.
+        :type validation_cfg: list(str) or None
+        """
         # global params
         if default_config_paths is None:
             default_config_paths = []
@@ -99,22 +106,24 @@ class ConfigHandler(object):
         if max_machine_core is not None:
             Machine.set_max_cores_per_chip(max_machine_core)
 
-        self._app_data_runtime_folder = None
-        self._app_data_top_simulation_folder = None
         self._json_folder = None
         self._provenance_file_path = None
         self._report_default_directory = None
         self._report_simulation_top_directory = None
         self._this_run_time_string = None
 
+    @property
+    def config(self):
+        return self._config
+
     def _adjust_config(self, runtime, debug_enable_opts, report_disable_opts):
         """ Adjust and checks config based on runtime and mode
 
         :param runtime:
         :type runtime: int or bool
-        :type debug_enable_opts: frozenset(str)
-        :type report_disable_opts: frozenset(str)
-        :raises ConfigurationException
+        :param frozenset(str) debug_enable_opts:
+        :param frozenset(str) report_disable_opts:
+        :raises ConfigurationException:
         """
         if self._config.get("Mode", "mode") == "Debug":
             for option in self._config.options("Reports"):
@@ -173,10 +182,15 @@ class ConfigHandler(object):
 
     def child_folder(self, parent, child_name, must_create=False):
         """
-        :param must_create: If `True`, the directory named by `child_name`\
-            (but not necessarily its parents) must be created by this call,\
-            and an exception will be thrown if this fails.
-        :raises OSError: if the directory existed ahead of time and creation\
+        :param str parent:
+        :param str child_name:
+        :param bool must_create:
+            If `True`, the directory named by `child_name` (but not necessarily
+            its parents) must be created by this call, and an exception will be
+            thrown if this fails.
+        :return: The fully qualified name of the child folder.
+        :rtype: str
+        :raises OSError: if the directory existed ahead of time and creation
             was required by the user
         """
         child = os.path.join(parent, child_name)
@@ -229,10 +243,8 @@ class ConfigHandler(object):
 
     def _set_up_report_specifics(self, n_calls_to_run):
         """
-        :param n_calls_to_run: \
+        :param int n_calls_to_run:
             the counter of how many times run has been called.
-        :type n_calls_to_run: int
-        :return: The folder for this run, the time_stamp
         """
 
         default_report_file_path = self._config.get_str(
@@ -285,6 +297,12 @@ class ConfigHandler(object):
         with open(time_of_run_file_name, "w") as f:
             f.writelines(self._this_run_time_string)
 
+        if self._read_config_boolean("Logging",
+                                     "warnings_at_end_to_file"):
+            log_report_file = os.path.join(
+                self._report_default_directory, WARNING_LOGS_FILENAME)
+            logger.set_report_File(log_report_file)
+
     @staticmethod
     def __make_timestamp():
         now = datetime.datetime.now()
@@ -292,54 +310,18 @@ class ConfigHandler(object):
             now.year, now.month, now.day,
             now.hour, now.minute, now.second, now.microsecond)
 
-    def set_up_output_application_data_specifics(self, n_calls_to_run):
-        """
-        :param n_calls_to_run: \
-            the counter of how many times run has been called.
-        :type n_calls_to_run: int
-        :return: the run folder for this simulation to hold app data
-        """
-        where_to_write_application_data_files = self._config.get(
-            "Reports", "default_application_data_file_path")
-        if where_to_write_application_data_files == "DEFAULT":
-            where_to_write_application_data_files = os.getcwd()
-
-        application_generated_data_file_folder = self.child_folder(
-            where_to_write_application_data_files, APP_DIRNAME)
-        # add time stamped folder for this run
-        self._app_data_top_simulation_folder = self.child_folder(
-            application_generated_data_file_folder, self._this_run_time_string)
-
-        # remove folders that are old and above the limit
-        self._remove_excess_folders(
-            self._config.getint("Reports", "max_application_binaries_kept"),
-            application_generated_data_file_folder)
-
-        # store timestamp in latest/time_stamp
-        time_of_run_file_name = os.path.join(
-            self._app_data_top_simulation_folder, TIMESTAMP_FILENAME)
-        with open(time_of_run_file_name, "w") as f:
-            f.writelines(str(self._this_run_time_string))
-
-        # create sub folder within reports for sub runs
-        # (where changes need to be recorded)
-        self._app_data_runtime_folder = self.child_folder(
-            self._app_data_top_simulation_folder, "run_{}".format(
-                n_calls_to_run))
-
     def _set_up_output_folders(self, n_calls_to_run):
-        """ Sets up all outgoing folders by creating\
-            a new timestamp folder for each and clearing
+        """ Sets up all outgoing folders by creating a new timestamp folder
+            for each and clearing
 
+        :param int n_calls_to_run:
+            the counter of how many times run has been called.
         :rtype: None
         """
 
         # set up reports default folder
         self._set_up_report_specifics(n_calls_to_run)
 
-        # set up application report folder
-        self.set_up_output_application_data_specifics(n_calls_to_run)
-
         if self._read_config_boolean("Reports",
                                      "writePacmanExecutorProvenance"):
             self._pacman_executor_provenance_path = os.path.join(
@@ -370,17 +352,12 @@ class ConfigHandler(object):
             self._make_dirs(self._system_provenance_file_path)
 
     def write_finished_file(self):
-        """ Write a finished file that allows file removal to only remove \
+        """ Write a finished file that allows file removal to only remove
             folders that are finished.
         """
-        app_file_name = os.path.join(self._app_data_top_simulation_folder,
-                                     FINISHED_FILENAME)
-        with open(app_file_name, "w") as f:
-            f.writelines("finished")
-
-        app_file_name = os.path.join(self._report_simulation_top_directory,
-                                     FINISHED_FILENAME)
-        with open(app_file_name, "w") as f:
+        report_file_name = os.path.join(self._report_simulation_top_directory,
+                                        FINISHED_FILENAME)
+        with open(report_file_name, "w") as f:
             f.writelines("finished")
 
     def _read_config(self, section, item):
@@ -394,6 +371,10 @@ class ConfigHandler(object):
 
     @property
     def machine_time_step(self):
+        """ The machine timestep, in microseconds
+
+        :rtype: int
+        """
         return self._read_config_int("Machine", "machine_time_step")
 
     @machine_time_step.setter
@@ -402,6 +383,10 @@ class ConfigHandler(object):
 
     @property
     def time_scale_factor(self):
+        """ The time scaling factor.
+
+        :rtype: int
+        """
         return self._read_config_int("Machine", "time_scale_factor")
 
     @time_scale_factor.setter
@@ -411,12 +396,14 @@ class ConfigHandler(object):
     def set_up_timings(self, machine_time_step=None, time_scale_factor=None):
         """ Set up timings of the machine
 
-        :param machine_time_step:\
-            An explicitly specified time step for the machine.  If None,\
+        :param machine_time_step:
+            An explicitly specified time step for the machine.  If None,
             the value is read from the config
-        :param time_scale_factor:\
-            An explicitly specified time scale factor for the simulation.\
+        :type machine_time_step: int or None
+        :param time_scale_factor:
+            An explicitly specified time scale factor for the simulation.
             If None, the value is read from the config
+        :type time_scale_factor: int or None
         """
 
         # set up timings
