@@ -25,9 +25,15 @@ class ChipIOBufClearer(object):
     __slots__ = []
 
     def __call__(self, transceiver, executable_types):
+        """
+        :param ~spinnman.transceiver.Transceiver transceiver:
+        :param executable_types:
+        :type executable_types:
+            dict(ExecutableType,~spinn_machine.CoreSubsets)
+        """
+        if ExecutableType.USES_SIMULATION_INTERFACE in executable_types:
+            core_subsets = \
+                executable_types[ExecutableType.USES_SIMULATION_INTERFACE]
 
-        core_subsets = \
-            executable_types[ExecutableType.USES_SIMULATION_INTERFACE]
-
-        process = ClearIOBUFProcess(transceiver.scamp_connection_selector)
-        process.clear_iobuf(core_subsets, len(core_subsets))
+            process = ClearIOBUFProcess(transceiver.scamp_connection_selector)
+            process.clear_iobuf(core_subsets, len(core_subsets))
