@@ -50,19 +50,24 @@ class RouterProvenanceGatherer(object):
     ]
 
     def __call__(
-            self, transceiver, machine, router_tables,
-            extra_monitor_vertices=None, placements=None):
+            self, transceiver, machine, router_tables, using_reinjection,
+            provenance_data_objects=None, extra_monitor_vertices=None,
+            placements=None):
         """
-        :param transceiver: the SpiNNMan interface object
-        :type transceiver: ~spinnman.transceiver.Transceiver
-        :param machine: the SpiNNaker machine
-        :type machine: ~spinn_machine.Machine
+        :param ~spinnman.transceiver.Transceiver transceiver:
+            the SpiNNMan interface object
+        :param ~spinn_machine.Machine machine:
+            the SpiNNaker machine
         :param router_tables: the router tables that have been generated
-        :param has_ran: token that states that the simulation has ran
-        :param provenance_data_objects: other provenance data items
-        :param extra_monitor_vertices: \
+        :type router_tables:
+            ~pacman.model.routing_tables.MulticastRoutingTables
+        :param bool using_reinjection: whether we are reinjecting packets
+        :param list(ProvenanceDataItem) provenance_data_objects:
+            any existing provenance information to add to
+        :param list(ExtraMonitorSupportMachineVertex) extra_monitor_vertices:
             vertices which represent the extra monitor code
-        :param placements: the placements object
+        :param ~pacman.model.placements.Placements placements:
+            the placements object
         """
         # pylint: disable=too-many-arguments
         # pylint: disable=attribute-defined-outside-init
@@ -75,10 +80,13 @@ class RouterProvenanceGatherer(object):
         self._machine = machine
         self._placements = placements
 
-        prov_items = list()
+        if provenance_data_objects is not None:
+            prov_items = provenance_data_objects
+        else:
+            prov_items = list()
 
-        prov_items.extend(self._write_router_provenance_data(
-            router_tables, extra_monitor_vertices))
+        self._add_router_provenance_data(
+            router_tables, extra_monitor_vertices, prov_items)
 
         prov_items.append(ProvenanceDataItem(
             ["router_provenance", "total_multi_cast_sent_packets"],
@@ -98,19 +106,20 @@ class RouterProvenanceGatherer(object):
 
         return prov_items
 
-    def _write_router_provenance_data(
-            self, router_tables, extra_monitor_vertices):
+    def _add_router_provenance_data(
+            self, router_tables, extra_monitor_vertices, items):
         """ Writes the provenance data of the router diagnostics
 
-        :param router_tables: the routing tables generated by PACMAN
-        :param extra_monitor_vertices: list of extra monitor vertices
+        :param ~.MulticastRoutingTables router_tables:
+            the routing tables generated by PACMAN
+        :param list(ExtraMonitorSupportMachineVertex) extra_monitor_vertices:
+            list of extra monitor vertices
+        :param list(ProvenanceDataItem) items:
         """
         # pylint: disable=too-many-arguments
         progress = ProgressBar(self._machine.n_chips*2,
                                "Getting Router Provenance")
 
-        # acquire diagnostic data
-        items = list()
         seen_chips = set()
 
         # get all extra monitor core data if it exists
@@ -125,18 +134,25 @@ class RouterProvenanceGatherer(object):
         for router_table in progress.over(sorted(
                 router_tables.routing_tables,
                 key=lambda table: (table.x, table.y)), False):
-            self._write_router_table_diagnostic(
+            self._add_router_table_diagnostic(
                 router_table.x, router_table.y, seen_chips,
                 router_table, items, reinjection_data)
 
         for chip in progress.over(sorted(
                 self._machine.chips, key=lambda c: (c.x, c.y))):
-            self._write_router_chip_diagnostic(
+            self._add_router_chip_diagnostic(
                 chip, seen_chips, items, reinjection_data)
-        return items
 
-    def _write_router_table_diagnostic(
+    def _add_router_table_diagnostic(
             self, x, y, seen_chips, router_table, items, reinjection_data):
+        """
+        :param int x:
+        :param int y:
+        :param set(tuple(int,int)) seen_chips:
+        :param ~.MulticastRoutingTable router_table:
+        :param list(ProvenanceDataItem) items:
+        :param dict(tuple(int,int),ReInjectionStatus) reinjection_data:
+        """
         # pylint: disable=too-many-arguments, bare-except
         if not self._machine.get_chip_at(x, y).virtual:
             try:
@@ -144,19 +160,25 @@ class RouterProvenanceGatherer(object):
                 seen_chips.add((x, y))
                 reinjection_status = None
                 if reinjection_data is not None:
-                    reinjection_status = reinjection_data[(x, y)]
-                items.extend(self._write_router_diagnostics(
-                    x, y, router_diagnostic, reinjection_status, True,
-                    router_table))
+                    reinjection_status = reinjection_data[x, y]
+                self.__add_router_diagnostics(
+                    items, x, y, router_diagnostic, reinjection_status, True,
+                    router_table)
                 self._add_totals(router_diagnostic, reinjection_status)
             except:  # noqa: E722
                 logger.warning(
                     "Could not read routing diagnostics from {}, {}",
                     x, y, exc_info=True)
 
-    def _write_router_chip_diagnostic(
+    def _add_router_chip_diagnostic(
             self, chip, seen_chips, items, reinjection_data):
-        # pylint: disable=too-many-arguments, bare-except
+        """
+        :param ~.Chip chip:
+        :param set(tuple(int,int)) seen_chips:
+        :param list(ProvenanceDataItem) items:
+        :param dict(tuple(int,int),ReInjectionStatus) reinjection_data:
+        """
+        # pylint: disable=bare-except
         if not chip.virtual and (chip.x, chip.y) not in seen_chips:
             try:
                 diagnostic = self._txrx.get_router_diagnostics(chip.x, chip.y)
@@ -167,15 +189,19 @@ class RouterProvenanceGatherer(object):
                     reinjection_status = None
                     if reinjection_data is not None:
                         reinjection_status = reinjection_data[chip.x, chip.y]
-                    items.extend(self._write_router_diagnostics(
-                            chip.x, chip.y, diagnostic, reinjection_status,
-                            False, None))
+                    self.__add_router_diagnostics(
+                        items, chip.x, chip.y, diagnostic, reinjection_status,
+                        False, None)
                     self._add_totals(diagnostic, reinjection_status)
             except:  # noqa: E722
                 # There could be issues with unused chips - don't worry!
                 pass
 
     def _add_totals(self, router_diagnostic, reinjection_status):
+        """
+        :param ~.RouterDiagnostics router_diagnostic:
+        :param ReInjectionStatus reinjection_status:
+        """
         self._total_sent_packets += (
             router_diagnostic.n_local_multicast_packets +
             router_diagnostic.n_external_multicast_packets)
@@ -192,22 +218,30 @@ class RouterProvenanceGatherer(object):
                 router_diagnostic.n_dropped_multicast_packets)
 
     @staticmethod
-    def _add_name(names, name):
+    def __add_name(names, name):
+        """
+        :param list(str) names:
+        :param str name:
+        :rtype: list(str)
+        """
         new_names = list(names)
         new_names.append(name)
         return new_names
 
-    def _write_router_diagnostics(
-            self, x, y, router_diagnostic, reinjection_status, expected,
-            router_table):
-        """ Stores router diagnostics as a set of provenance data items
+    def __add_router_diagnostics(
+            self, items, x, y, router_diagnostic, reinjection_status,
+            expected, router_table):
+        """ Stores router diagnostics as a set of provenance data items.
 
-        :param x: x coordinate of the router in question
-        :param y: y coordinate of the router in question
-        :param router_diagnostic: the router diagnostic object
-        :param reinjection_status: \
+        :param list(ProvenanceDataItem) items: the list to append to
+        :param int x: x coordinate of the router in question
+        :param int y: y coordinate of the router in question
+        :param ~.RouterDiagnostics router_diagnostic:
+            the router diagnostic object
+        :param ReInjectionStatus reinjection_status:
             the data gained from the extra monitor re-injection subsystem
-        :param router_table: the router table generated by the PACMAN tools
+        :param ~.MulticastRoutingTable router_table:
+            the router table generated by the PACMAN tools
         """
         # pylint: disable=too-many-arguments
         names = list()
@@ -218,27 +252,38 @@ class RouterProvenanceGatherer(object):
             names.append("unexpected_routers")
         names.append("router_at_chip_{}_{}".format(x, y))
 
-        items = list()
-
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Local_Multicast_Packets"),
+            self.__add_name(names, "Local_Multicast_Packets"),
             str(router_diagnostic.n_local_multicast_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "External_Multicast_Packets"),
+            self.__add_name(names, "External_Multicast_Packets"),
             str(router_diagnostic.n_external_multicast_packets)))
+
+        # simplify the if by making components of it outside.
+        has_dropped = router_diagnostic.n_dropped_multicast_packets > 0
+        missing_stuff = None
+        has_reinjection = reinjection_status is not None
+        if has_reinjection:
+            missing_stuff = (
+                (reinjection_status.n_dropped_packets +
+                 reinjection_status.n_missed_dropped_packets +
+                 reinjection_status.n_dropped_packet_overflows +
+                 reinjection_status.n_reinjected_packets +
+                 reinjection_status.n_link_dumps +
+                 reinjection_status.n_processor_dumps) <
+                router_diagnostic.n_dropped_multicast_packets)
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Dropped_Multicast_Packets"),
+            self.__add_name(names, "Dropped_Multicast_Packets"),
             str(router_diagnostic.n_dropped_multicast_packets),
-            report=(
-                router_diagnostic.n_dropped_multicast_packets > 0 and
-                reinjection_status is None),
+            report=((has_dropped and not has_reinjection) or (
+                has_dropped and has_reinjection and missing_stuff)),
             message=(
                 "The router on {}, {} has dropped {} multicast route packets. "
                 "Try increasing the machine_time_step and/or the time scale "
                 "factor or reducing the number of atoms per core."
                 .format(x, y, router_diagnostic.n_dropped_multicast_packets))))
         items.append(ProvenanceDataItem(
-            self._add_name(
+            self.__add_name(
                 names, "Dropped_Multicast_Packets_via_local_transmission"),
             str(router_diagnostic.user_3),
             report=(router_diagnostic.user_3 > 0),
@@ -250,7 +295,8 @@ class RouterProvenanceGatherer(object):
                 "the router table entries for this chip.".format(
                     x, y, router_diagnostic.user_3))))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "default_routed_external_multicast_packets"),
+            self.__add_name(
+                names, "default_routed_external_multicast_packets"),
             str(router_diagnostic.user_2),
             report=(router_diagnostic.user_2 > 0 and
                     ((router_table is not None and
@@ -266,31 +312,31 @@ class RouterProvenanceGatherer(object):
                     x, y, router_diagnostic.user_2))))
 
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Local_P2P_Packets"),
+            self.__add_name(names, "Local_P2P_Packets"),
             str(router_diagnostic.n_local_peer_to_peer_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "External_P2P_Packets"),
+            self.__add_name(names, "External_P2P_Packets"),
             str(router_diagnostic.n_external_peer_to_peer_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Dropped_P2P_Packets"),
+            self.__add_name(names, "Dropped_P2P_Packets"),
             str(router_diagnostic.n_dropped_peer_to_peer_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Local_NN_Packets"),
+            self.__add_name(names, "Local_NN_Packets"),
             str(router_diagnostic.n_local_nearest_neighbour_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "External_NN_Packets"),
+            self.__add_name(names, "External_NN_Packets"),
             str(router_diagnostic.n_external_nearest_neighbour_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Dropped_NN_Packets"),
+            self.__add_name(names, "Dropped_NN_Packets"),
             str(router_diagnostic.n_dropped_nearest_neighbour_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Local_FR_Packets"),
+            self.__add_name(names, "Local_FR_Packets"),
             str(router_diagnostic.n_local_fixed_route_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "External_FR_Packets"),
+            self.__add_name(names, "External_FR_Packets"),
             str(router_diagnostic.n_external_fixed_route_packets)))
         items.append(ProvenanceDataItem(
-            self._add_name(names, "Dropped_FR_Packets"),
+            self.__add_name(names, "Dropped_FR_Packets"),
             str(router_diagnostic.n_dropped_fixed_route_packets),
             report=router_diagnostic.n_dropped_fixed_route_packets > 0,
             message=(
@@ -301,10 +347,10 @@ class RouterProvenanceGatherer(object):
                     x, y, router_diagnostic.n_dropped_fixed_route_packets))))
         if reinjection_status is not None:
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Received_For_Reinjection"),
+                self.__add_name(names, "Received_For_Reinjection"),
                 reinjection_status.n_dropped_packets))
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Missed_For_Reinjection"),
+                self.__add_name(names, "Missed_For_Reinjection"),
                 reinjection_status.n_missed_dropped_packets,
                 report=reinjection_status.n_missed_dropped_packets > 0,
                 message=(
@@ -312,7 +358,7 @@ class RouterProvenanceGatherer(object):
                     "packets.".format(
                         x, y, reinjection_status.n_missed_dropped_packets))))
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Reinjection_Overflows"),
+                self.__add_name(names, "Reinjection_Overflows"),
                 reinjection_status.n_dropped_packet_overflows,
                 report=reinjection_status.n_dropped_packet_overflows > 0,
                 message=(
@@ -321,12 +367,13 @@ class RouterProvenanceGatherer(object):
                         x, y,
                         reinjection_status.n_dropped_packet_overflows))))
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Reinjected"),
+                self.__add_name(names, "Reinjected"),
                 reinjection_status.n_reinjected_packets))
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Dumped_from_a_Link"),
+                self.__add_name(names, "Dumped_from_a_Link"),
                 str(reinjection_status.n_link_dumps),
-                report=reinjection_status.n_link_dumps > 0,
+                report=(reinjection_status.n_link_dumps > 0 and
+                        self._has_virtual_chip_connected(self._machine, x, y)),
                 message=(
                     "The extra monitor on {}, {} has detected that {} packets "
                     "were dumped from a outgoing link of this chip's router."
@@ -336,7 +383,7 @@ class RouterProvenanceGatherer(object):
                     "multiple times and so this number may be a overestimate."
                     .format(x, y, reinjection_status.n_link_dumps))))
             items.append(ProvenanceDataItem(
-                self._add_name(names, "Dumped_from_a_processor"),
+                self.__add_name(names, "Dumped_from_a_processor"),
                 str(reinjection_status.n_processor_dumps),
                 report=reinjection_status.n_processor_dumps > 0,
                 message=(
@@ -348,4 +395,28 @@ class RouterProvenanceGatherer(object):
                     " each packet. These packets were reinjected and so this"
                     " number is likely a overestimate.".format(
                         x, y, reinjection_status.n_processor_dumps))))
-        return items
+
+        items.append(ProvenanceDataItem(
+            self.__add_name(names, "Error status"),
+            str(router_diagnostic.error_status),
+            report=router_diagnostic.error_status > 0,
+            message=(
+                "The router on {}, {} has a non-zero error status.  This could"
+                " indicate a hardware fault.  The errors set are {}, and the"
+                " error count is {}".format(
+                    x, y, router_diagnostic.errors_set,
+                    router_diagnostic.error_count))))
+
+    @staticmethod
+    def _has_virtual_chip_connected(machine, x, y):
+        """
+        :param ~.Machine machine:
+        :param int x:
+        :param int y:
+        :rtype: bool
+        """
+        for link in machine.get_chip_at(x, y).router.links:
+            if machine.get_chip_at(
+                    link.destination_x, link.destination_y).virtual:
+                return True
+        return False
