@@ -20,8 +20,8 @@ import os
 import subprocess
 from spinn_utilities.log import FormatAdapter
 from pacman.exceptions import PacmanExternalAlgorithmFailedToCompleteException
-from pacman.utilities.file_format_converters.convert_to_java_machine import (
-    ConvertToJavaMachine)
+from pacman.operations.algorithm_reports.write_json_machine import (
+    WriteJsonMachine)
 from spinn_front_end_common.utilities.exceptions import ConfigurationException
 from spinn_front_end_common.interface.buffer_management.buffer_models import (
     AbstractReceiveBuffersToHost)
@@ -70,21 +70,20 @@ class JavaCaller(object):
                  java_properties=None):
         """ Creates a java caller and checks the user/config parameters.
 
-        :param json_folder: The location where the machine JSON is written.
-        :type json_folder: str
-        :param java_call: Call to start java. Including the path if required.
-        :type java_call: str
-        :param java_spinnaker_path: the path where the java code can be found.
-            This must point to a local copy of \
-            https://github.com/SpiNNakerManchester/JavaSpiNNaker. \
-            It must also have been built! \
-            If None the assumption is that it is the same parent directory as \
-            https://github.com/SpiNNakerManchester/SpiNNFrontEndCommon.
-        :param java_properties:
+        :param str json_folder: The location where the machine JSON is written.
+        :param str java_call:
+            Call to start java. Including the path if required.
+        :param str java_spinnaker_path:
+            The path where the java code can be found.
+            This must point to a local copy of
+            `https://github.com/SpiNNakerManchester/JavaSpiNNaker`.
+            It must also have been built!
+            If `None` the assumption is that it is the same parent directory as
+            `https://github.com/SpiNNakerManchester/SpiNNFrontEndCommon`.
+        :param str java_properties:
             Optional properties that will be passed to Java.\
             Must start with ``-D``.
             For example ``-Dlogging.level=DEBUG``
-        :type java_properties: str
         :raise ConfigurationException: if simple parameter checking fails.
         """
         self._recording = None
@@ -137,22 +136,22 @@ class JavaCaller(object):
     def set_machine(self, machine):
         """ Passes the machine in leaving this class to decide pass it to Java.
 
-        :param machine: A machine Object
-        :type machine: ~spinn_machine.Machine
+        :param ~spinn_machine.Machine machine: A machine Object
         """
         self._machine = machine
 
     def set_advanced_monitors(
             self, placements, tags, monitor_cores, packet_gathers):
         """
-        :param placements: The placements of the vertices
-        :type placements: ~pacman.model.placements.Placements
-        :param tags: The tags assigned to the vertices
-        :type tags: ~pacman.model.tags.Tags
+        :param ~pacman.model.placements.Placements placements:
+            The placements of the vertices
+        :param ~pacman.model.tags.Tags tags: The tags assigned to the vertices
         :param monitor_cores: Where the advanced monitor for each core is
-        :type monitor_cores: dict(Vertex,Vertex)
+        :type monitor_cores:
+            dict(tuple(int,int), ExtraMonitorSupportMachineVertex)
         :param packet_gathers: Where the packet gatherers are
-        :type packet_gathers: dict(Vertex,Vertex)
+        :type packet_gathers:
+            dict(tuple(int,int), DataSpeedUpPacketGatherMachineVertex)
         :rtype: None
         """
         self._monitor_cores = dict()
@@ -181,38 +180,36 @@ class JavaCaller(object):
         :return: the name of the file containing the JSON
         """
         if self._machine_json_path is None:
-            path = os.path.join(self._json_folder, "machine.json")
-            self._machine_json_path = ConvertToJavaMachine.do_convert(
-                self._machine, path)
+            self._machine_json_path = WriteJsonMachine.write_json(
+                self._machine, self._json_folder)
         return self._machine_json_path
 
     def set_report_folder(self, report_folder):
         """ Passes the database file in.
 
-        :param report_folder: Path to directory with SQLite databases\
-            and into which java will write
-        :type report_folder: str
+        :param str report_folder:
+            Path to directory with SQLite databases and into which java will
+            write.
         """
         self._report_folder = report_folder
 
     def set_placements(self, placements, transceiver):
-        """ Passes in the placements leaving this class to decide pass it to\
+        """ Passes in the placements leaving this class to decide pass it to
             Java.
 
-        This method may obtain extra information about he placements which is\
+        This method may obtain extra information about he placements which is
         why it also needs the transceiver.
 
-        Currently the extra information extracted is recording region\
-        base address but this could change if recording region saved in\
-        the database.
-
-        Currently this method uses JSON but that may well change to using the\
+        Currently the extra information extracted is recording region base
+        address but this could change if recording region saved in the
         database.
 
-        :param placements: The Placements Object
-        :type placements: ~pacman.model.placements.Placements
-        :param transceiver: The Transceiver
-        :type transceiver: ~spinnman.transceiver.Transceiver
+        Currently this method uses JSON but that may well change to using the
+        database.
+
+        :param ~pacman.model.placements.Placements placements:
+            The Placements Object
+        :param ~spinnman.transceiver.Transceiver transceiver: The Transceiver
         """
         path = os.path.join(self._json_folder, "java_placements.json")
         self._recording = False
@@ -224,7 +221,11 @@ class JavaCaller(object):
                 placements, transceiver, path)
 
     def _json_placement(self, placement, transceiver):
-
+        """
+        :param ~pacman.model.placements.Placement placement:
+        :param ~spinnman.transceiver.Transceiver transceiver:
+        :rtype: dict
+        """
         vertex = placement.vertex
         json_placement = OrderedDict()
         json_placement["x"] = placement.x
@@ -248,6 +249,10 @@ class JavaCaller(object):
         return json_placement
 
     def _json_iptag(self, iptag):
+        """
+        :param ~pacman.model.tags.IPTag iptag:
+        :rtype: dict
+        """
         json_tag = OrderedDict()
         json_tag["x"] = iptag.destination_x
         json_tag["y"] = iptag.destination_y
@@ -261,6 +266,11 @@ class JavaCaller(object):
         return json_tag
 
     def _placements_grouped(self, placements):
+        """
+        :param ~pacman.model.placements.Placements placements:
+        :rtype: dict(tuple(int,int),dict(tuple(int,int),
+            ~pacman.model.placements.Placement))
+        """
         by_ethernet = defaultdict(lambda: defaultdict(list))
         for placement in placements:
             chip = self._machine.get_chip_at(placement.x, placement.y)
@@ -270,7 +280,12 @@ class JavaCaller(object):
         return by_ethernet
 
     def _write_gather(self, placements, transceiver, path):
-
+        """
+        :param ~pacman.model.placements.Placements placements:
+        :param ~spinnman.transceiver.Transceiver transceiver:
+        :param str path:
+        :rtype: str
+        """
         placements_by_ethernet = self._placements_grouped(placements)
         json_obj = list()
         for ethernet in self._chipxy_by_ethernet:
@@ -306,6 +321,12 @@ class JavaCaller(object):
         return path
 
     def _write_placements(self, placements, transceiver, path):
+        """
+        :param ~pacman.model.placements.Placements placements:
+        :param ~spinnman.transceiver.Transceiver transceiver:
+        :param str path:
+        :rtype: str
+        """
         # Read back the regions
         json_obj = list()
         for placement in placements:
@@ -321,6 +342,10 @@ class JavaCaller(object):
 
     @property
     def _jar_file(self):
+        """ The fully qualified name of the JavaSpiNNaker executable JAR.
+
+        :rtype: str
+        """
         f = os.path.join(
             self._java_spinnaker_path, "SpiNNaker-front-end",
             "target", "spinnaker-exe.jar")
@@ -329,6 +354,11 @@ class JavaCaller(object):
         return f
 
     def _run_java(self, *args):
+        """ Does the actual running of JavaSpiNNaker. Arguments are those that
+            will be processed by the `main` method on the Java side.
+
+        :rtype: int
+        """
         if self._java_properties is None:
             params = [self._java_call, '-jar', self._jar_file]
         else:
@@ -338,8 +368,11 @@ class JavaCaller(object):
         return subprocess.call(params)
 
     def get_all_data(self):
-        """ Gets all the data from the previously set placements\
+        """ Gets all the data from the previously set placements
             and put these in the previously set database.
+
+        :raises PacmanExternalAlgorithmFailedToCompleteException:
+            On failure of the Java code.
         """
         if not self._recording:
             return
@@ -360,6 +393,9 @@ class JavaCaller(object):
 
     def execute_data_specification(self):
         """ Writes all the data specs, uploading the result to the machine.
+
+        :raises PacmanExternalAlgorithmFailedToCompleteException:
+            On failure of the Java code.
         """
         result = self._run_java(
             'dse', self._machine_json(), self._report_folder)
@@ -370,8 +406,11 @@ class JavaCaller(object):
                 + str(log_file) + " for logged info")
 
     def execute_system_data_specification(self):
-        """ Writes all the data specs for system cores, \
+        """ Writes all the data specs for system cores,
             uploading the result to the machine.
+
+        :raises PacmanExternalAlgorithmFailedToCompleteException:
+            On failure of the Java code.
         """
         result = self._run_java(
             'dse_sys', self._machine_json(), self._report_folder)
@@ -382,11 +421,16 @@ class JavaCaller(object):
                 + str(log_file) + " for logged info")
 
     def execute_app_data_specification(self, use_monitors):
-        """ Writes all the data specs for application cores, \
+        """ Writes all the data specs for application cores,
             uploading the result to the machine.
 
         .. note:
-            May assume that system cores are already loaded and running.
+            May assume that system cores are already loaded and running if
+            `use_monitors` is set to `True`.
+
+        :param bool use_monitors:
+        :raises PacmanExternalAlgorithmFailedToCompleteException:
+            On failure of the Java code.
         """
         if use_monitors:
             result = self._run_java(
