@@ -13,13 +13,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from six import add_metaclass
 from spinn_utilities.abstract_base import AbstractBase, abstractmethod
+from spinn_utilities.require_subclass import require_subclass
+from pacman.model.graphs.machine import MachineVertex
 
 
-@add_metaclass(AbstractBase)
-class AbstractHasProfileData(object):
-    """ Indicates an object that can record a profile
+@require_subclass(MachineVertex)
+class AbstractHasProfileData(object, metaclass=AbstractBase):
+    """ Indicates a :py:class:`~pacman.model.graphs.machine.MachineVertex` \
+        that can record a profile.
     """
     __slots__ = ()
 
@@ -27,6 +29,7 @@ class AbstractHasProfileData(object):
     def get_profile_data(self, transceiver, placement):
         """ Get the profile data recorded during simulation
 
-        :rtype:\
-            :py:class:`spinn_front_end_common.interface.profiling.profile_data.ProfileData`
+        :param ~spinnman.transceiver.Transceiver transceiver:
+        :param ~pacman.model.placements.Placement placement:
+        :rtype: ~spinn_front_end_common.interface.profiling.ProfileData
         """
