@@ -18,10 +18,13 @@ from .abstract_provides_local_provenance_data import (
 from .abstract_provides_provenance_data_from_machine import (
     AbstractProvidesProvenanceDataFromMachine)
 from .pacman_provenance_extractor import PacmanProvenanceExtractor
+from .provenance_reader import ProvenanceReader
 from .provides_provenance_data_from_machine_impl import (
     ProvidesProvenanceDataFromMachineImpl)
+from .sqllite_database import SqlLiteDatabase
 
 __all__ = ["AbstractProvidesLocalProvenanceData",
            "AbstractProvidesProvenanceDataFromMachine",
-           "PacmanProvenanceExtractor",
-           "ProvidesProvenanceDataFromMachineImpl"]
+           "PacmanProvenanceExtractor", "ProvenanceReader",
+           "ProvidesProvenanceDataFromMachineImpl",
+           "SqlLiteDatabase"]
