@@ -15,10 +15,8 @@
 
 import logging
 import struct
-import sys
 from threading import Thread
 from collections import OrderedDict
-from six import iterkeys, iteritems, reraise
 from spinn_utilities.log import FormatAdapter
 from spinnman.messages.eieio.data_messages import (
     EIEIODataMessage, KeyPayloadDataElement)
@@ -77,24 +75,23 @@ class LiveEventConnection(DatabaseConnection):
                  send_labels=None, local_host=None, local_port=NOTIFY_PORT,
                  machine_vertices=False):
         """
-        :param live_packet_gather_label: The label of the LivePacketGather\
-            vertex to which received events are being sent
-        :param receive_labels: \
+        :param str live_packet_gather_label:
+            The label of the :py:class:`LivePacketGather` vertex to which
+            received events are being sent
+        :param iterable(str) receive_labels:
             Labels of vertices from which live events will be received.
-        :type receive_labels: iterable(str)
-        :param send_labels: \
+        :param iterable(str) send_labels:
             Labels of vertices to which live events will be sent
-        :type send_labels: iterable(str)
-        :param local_host: Optional specification of the local hostname or\
-            IP address of the interface to listen on
-        :type local_host: str
-        :param local_port: Optional specification of the local port to listen\
-            on. Must match the port that the toolchain will send the\
-            notification on (19999 by default)
-        :type local_port: int
+        :param str local_host:
+            Optional specification of the local hostname or IP address of the
+            interface to listen on
+        :param int local_port:
+            Optional specification of the local port to listen on. Must match
+            the port that the toolchain will send the notification on (19999
+            by default)
         """
         # pylint: disable=too-many-arguments
-        super(LiveEventConnection, self).__init__(
+        super().__init__(
             self.__do_start_resume, self.__do_stop_pause,
             local_host=local_host, local_port=local_port)
 
@@ -154,15 +151,15 @@ class LiveEventConnection(DatabaseConnection):
     def add_init_callback(self, label, init_callback):
         """ Add a callback to be called to initialise a vertex
 
-        :param label: The label of the vertex to be notified about. Must be\
-            one of the vertices listed in the constructor
-        :type label: str
-        :param init_callback: A function to be called to initialise the\
-            vertex. This should take as parameters the label of the vertex,\
-            the number of neurons in the population, the run time of the\
-            simulation in milliseconds, and the simulation timestep in\
+        :param str label:
+            The label of the vertex to be notified about. Must be one of the
+            vertices listed in the constructor
+        :param init_callback: A function to be called to initialise the
+            vertex. This should take as parameters the label of the vertex,
+            the number of neurons in the population, the run time of the
+            simulation in milliseconds, and the simulation timestep in
             milliseconds
-        :type init_callback: function(str, int, float, float) -> None
+        :type init_callback: callable(str, int, float, float) -> None
         """
         self.__init_callbacks[label].append(init_callback)
 
@@ -170,16 +167,16 @@ class LiveEventConnection(DatabaseConnection):
                              translate_key=True):
         """ Add a callback for the reception of live events from a vertex
 
-        :param label: The label of the vertex to be notified about. Must be\
-            one of the vertices listed in the constructor
-        :type label: str
-        :param live_event_callback: A function to be called when events are\
-            received. This should take as parameters the label of the vertex,\
-            the simulation timestep when the event occurred, and an\
+        :param str label: The label of the vertex to be notified about.
+            Must be one of the vertices listed in the constructor
+        :param live_event_callback: A function to be called when events are
+            received. This should take as parameters the label of the vertex,
+            the simulation timestep when the event occurred, and an
             array-like of atom IDs.
-        :type live_event_callback: function(str, int, list(int)) -> None
-        :param translate_key: True if the key is to be converted to an atom\
-            ID, False if the key should stay a key
+        :type live_event_callback: callable(str, int, list(int)) -> None
+        :param bool translate_key:
+            True if the key is to be converted to an atom ID, False if the
+            key should stay a key
         """
         label_id = self.__receive_labels.index(label)
         logger.info("Receive callback {} registered to label {}".format(
@@ -190,14 +187,12 @@ class LiveEventConnection(DatabaseConnection):
     def add_start_callback(self, label, start_callback):
         """ Add a callback for the start of the simulation
 
-        :param start_callback: A function to be called when the start\
-            message has been received. This function should take the label of\
-            the referenced vertex, and an instance of this class, which can\
+        :param start_callback: A function to be called when the start
+            message has been received. This function should take the label of
+            the referenced vertex, and an instance of this class, which can
             be used to send events
-        :type start_callback: function(str, \
-            :py:class:`SpynnakerLiveEventConnection`) -> None
-        :param label: the label of the function to be sent
-        :type label: str
+        :type start_callback: callable(str, LiveEventConnection) -> None
+        :param str label: the label of the function to be sent
         """
         logger.warning(
             "the method 'add_start_callback(label, start_callback)' is in "
@@ -209,14 +204,12 @@ class LiveEventConnection(DatabaseConnection):
     def add_start_resume_callback(self, label, start_resume_callback):
         """ Add a callback for the start and resume state of the simulation
 
-        :param label: the label of the function to be sent
-        :type label: str
-        :param start_resume_callback: A function to be called when the start\
-            or resume message has been received. This function should take \
-            the label of the referenced vertex, and an instance of this \
+        :param str label: the label of the function to be sent
+        :param start_resume_callback: A function to be called when the start
+            or resume message has been received. This function should take
+            the label of the referenced vertex, and an instance of this
             class, which can be used to send events.
-        :type start_resume_callback: function(str, \
-            :py:class:`SpynnakerLiveEventConnection`) -> None
+        :type start_resume_callback: callable(str, LiveEventConnection) -> None
         :rtype: None
         """
         self.__start_resume_callbacks[label].append(start_resume_callback)
@@ -224,19 +217,20 @@ class LiveEventConnection(DatabaseConnection):
     def add_pause_stop_callback(self, label, pause_stop_callback):
         """ Add a callback for the pause and stop state of the simulation
 
-        :param label: the label of the function to be sent
-        :type label: str
-        :param pause_stop_callback: A function to be called when the pause\
-            or stop message has been received. This function should take the\
-            label of the referenced  vertex, and an instance of this class,\
+        :param str label: the label of the function to be sent
+        :param pause_stop_callback: A function to be called when the pause
+            or stop message has been received. This function should take the
+            label of the referenced  vertex, and an instance of this class,
             which can be used to send events.
-        :type pause_stop_callback: function(str, \
-            :py:class:`SpynnakerLiveEventConnection`) -> None
+        :type pause_stop_callback: callable(str, LiveEventConnection) -> None
         :rtype: None
         """
         self.__pause_stop_callbacks[label].append(pause_stop_callback)
 
     def __read_database_callback(self, db_reader):
+        """
+        :param DatabaseReader db_reader:
+        """
         self.__handle_possible_rerun_state()
 
         vertex_sizes = OrderedDict()
@@ -251,12 +245,16 @@ class LiveEventConnection(DatabaseConnection):
         if self.__receive_labels is not None:
             self.__init_receivers(db_reader, vertex_sizes)
 
-        for label, vertex_size in iteritems(vertex_sizes):
+        for label, vertex_size in vertex_sizes.items():
             for init_callback in self.__init_callbacks[label]:
                 init_callback(
                     label, vertex_size, run_time_ms, machine_timestep_ms)
 
     def __init_sender(self, db, vertex_sizes):
+        """
+        :param DatabaseReader db:
+        :param dict(str,int) vertex_sizes:
+        """
         if self.__sender_connection is None:
             self.__sender_connection = UDPConnection()
         for label in self.__send_labels:
@@ -272,6 +270,10 @@ class LiveEventConnection(DatabaseConnection):
                 vertex_sizes[label] = len(self._atom_id_to_key[label])
 
     def __init_receivers(self, db, vertex_sizes):
+        """
+        :param DatabaseReader db:
+        :param dict(str,int) vertex_sizes:
+        """
         # Set up a single connection for receive
         if self.__receiver_connection is None:
             self.__receiver_connection = EIEIOConnection()
@@ -300,7 +302,7 @@ class LiveEventConnection(DatabaseConnection):
                 vertex_sizes[label] = 1
             else:
                 key_to_atom_id = db.get_key_to_atom_id_mapping(label)
-                for key, atom_id in iteritems(key_to_atom_id):
+                for key, atom_id in key_to_atom_id.items():
                     self.__key_to_atom_id_and_label[key] = (atom_id, label_id)
                 vertex_sizes[label] = len(key_to_atom_id)
 
@@ -314,6 +316,11 @@ class LiveEventConnection(DatabaseConnection):
             self.__receiver_listener.start()
 
     def __get_live_input_details(self, db_reader, send_label):
+        """
+        :param DatabaseReader db_reader:
+        :param str send_label:
+        :rtype: tuple(int,int,int,str or None)
+        """
         if self.__machine_vertices:
             x, y, p = db_reader.get_placement(send_label)
         else:
@@ -362,10 +369,10 @@ class LiveEventConnection(DatabaseConnection):
                 request.get_scp_response().read_bytestring(
                     response_data, _TWO_SKIP.size)
                 sent = True
-            except SpinnmanTimeoutException:
+            except SpinnmanTimeoutException as e:
                 if not tries_to_go:
                     logger.info("No more tries - Error!")
-                    reraise(*sys.exc_info())
+                    raise e
 
                 logger.info("Timeout, retrying")
                 tries_to_go -= 1
@@ -391,12 +398,12 @@ class LiveEventConnection(DatabaseConnection):
         thread.start()
 
     def __do_start_resume(self):
-        for label, callbacks in iteritems(self.__start_resume_callbacks):
+        for label, callbacks in self.__start_resume_callbacks.items():
             for callback in callbacks:
                 self.__launch_thread("start_resume", label, callback)
 
     def __do_stop_pause(self):
-        for label, callbacks in iteritems(self.__pause_stop_callbacks):
+        for label, callbacks in self.__pause_stop_callbacks.items():
             for callback in callbacks:
                 self.__launch_thread("pause_stop", label, callback)
 
@@ -431,8 +438,8 @@ class LiveEventConnection(DatabaseConnection):
             else:
                 self.__handle_unknown_key(key)
 
-        for time in iterkeys(key_times_labels):
-            for label_id in iterkeys(key_times_labels[time]):
+        for time in key_times_labels:
+            for label_id in key_times_labels[time]:
                 label = self.__receive_labels[label_id]
                 for c_back, use_atom in self.__live_event_callbacks[label_id]:
                     if use_atom:
@@ -469,30 +476,26 @@ class LiveEventConnection(DatabaseConnection):
     def send_event(self, label, atom_id, send_full_keys=False):
         """ Send an event from a single atom
 
-        :param label: \
+        :param str label:
             The label of the vertex from which the event will originate
-        :type label: str
-        :param atom_id: The ID of the atom sending the event
-        :type atom_id: int
-        :param send_full_keys: Determines whether to send full 32-bit keys,\
-            getting the key for each atom from the database, or whether to\
-            send 16-bit atom IDs directly
-        :type send_full_keys: bool
+        :param int atom_id: The ID of the atom sending the event
+        :param bool send_full_keys:
+            Determines whether to send full 32-bit keys, getting the key for
+            each atom from the database, or whether to send 16-bit atom IDs
+            directly
         """
         self.send_events(label, [atom_id], send_full_keys)
 
     def send_events(self, label, atom_ids, send_full_keys=False):
         """ Send a number of events
 
-        :param label: \
+        :param str label:
             The label of the vertex from which the events will originate
-        :type label: str
-        :param atom_ids: array-like of atom IDs sending events
-        :type atom_ids: list(int)
-        :param send_full_keys: Determines whether to send full 32-bit keys,\
-            getting the key for each atom from the database, or whether to\
-            send 16-bit atom IDs directly
-        :type send_full_keys: bool
+        :param list(int) atom_ids: array-like of atom IDs sending events
+        :param bool send_full_keys:
+            Determines whether to send full 32-bit keys, getting the key for
+            each atom from the database, or whether to send 16-bit atom IDs
+            directly
         """
         max_keys = _MAX_HALF_KEYS_PER_PACKET
         msg_type = EIEIOType.KEY_16_BIT
@@ -520,25 +523,20 @@ class LiveEventConnection(DatabaseConnection):
     def send_event_with_payload(self, label, atom_id, payload):
         """ Send an event with a payload from a single atom
 
-        :param label: \
+        :param str label:
             The label of the vertex from which the event will originate
-        :type label: str
-        :param atom_id: The ID of the atom sending the event
-        :type atom_id: int
-        :param payload: The payload to send
-        :type payload: int
+        :param int atom_id: The ID of the atom sending the event
+        :param int payload: The payload to send
         """
         self.send_events_with_payloads(label, [(atom_id, payload)])
 
     def send_events_with_payloads(self, label, atom_ids_and_payloads):
         """ Send a number of events with payloads
 
-        :param label: \
+        :param str label:
             The label of the vertex from which the events will originate
-        :type label: str
-        :param atom_ids_and_payloads:\
+        :param list(tuple(int,int)) atom_ids_and_payloads:
             array-like of tuples of atom IDs sending events with their payloads
-        :type atom_ids_and_payloads: list((int, int))
         """
         msg_type = EIEIOType.KEY_PAYLOAD_32_BIT
         max_keys = _MAX_FULL_KEYS_PAYLOADS_PER_PACKET
@@ -562,8 +560,9 @@ class LiveEventConnection(DatabaseConnection):
         """ Send an EIEIO message (using one-way the live input) to the \
             vertex with the given label.
 
-        :param message: The EIEIO message to send
-        :param label: The label of the receiver machine vertex
+        :param ~spinnman.messages.eieio.AbstractEIEIOMessage message:
+            The EIEIO message to send
+        :param str label: The label of the receiver machine vertex
         """
         target = self.__send_address_details[label]
         if target is None:
@@ -575,7 +574,7 @@ class LiveEventConnection(DatabaseConnection):
 
     def close(self):
         self.__handle_possible_rerun_state()
-        super(LiveEventConnection, self).close()
+        super().close()
 
     @staticmethod
     def __get_sdp_data(message, x, y, p):
