@@ -14,6 +14,5 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .notification_protocol import NotificationProtocol
-from .socket_address import SocketAddress
 
-__all__ = ["NotificationProtocol", "SocketAddress"]
+__all__ = ["NotificationProtocol"]
