@@ -13,15 +13,36 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+Much of the code in this module is intended primarily for being invoked via the
+PACMAN Executor.
+"""
+
+import os
+from .bit_field_compressor_report import BitFieldCompressorReport
+from .bit_field_summary import BitFieldSummary
+from .board_chip_report import BoardChipReport
 from .energy_report import EnergyReport
 from .fixed_route_from_machine_report import FixedRouteFromMachineReport
 from .memory_map_on_host_chip_report import MemoryMapOnHostChipReport
 from .memory_map_on_host_report import MemoryMapOnHostReport
 from .routing_table_from_machine_report import RoutingTableFromMachineReport
+from .real_tags_report import TagsFromMachineReport
+
+
+def report_xml():
+    return os.path.join(
+        os.path.dirname(__file__), "front_end_common_reports.xml")
+
 
 __all__ = [
+    "BitFieldCompressorReport",
+    "BitFieldSummary",
+    "BoardChipReport",
     "EnergyReport",
     "FixedRouteFromMachineReport",
     "MemoryMapOnHostChipReport",
     "MemoryMapOnHostReport",
-    "RoutingTableFromMachineReport"]
+    "report_xml",
+    "RoutingTableFromMachineReport",
+    "TagsFromMachineReport"]
