@@ -14,9 +14,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from .clear_iobuf_process import ClearIOBUFProcess
-from .scp_clear_iobuf_request import SCPClearIOBUFRequest
-from .scp_update_runtime_request import SCPUpdateRuntimeRequest
 from .update_runtime_process import UpdateRuntimeProcess
 
-__all__ = ["ClearIOBUFProcess", "SCPClearIOBUFRequest",
-           "SCPUpdateRuntimeRequest", "UpdateRuntimeProcess"]
+__all__ = ["ClearIOBUFProcess", "UpdateRuntimeProcess"]
