@@ -20,10 +20,13 @@ from spinn_front_end_common.utilities.utility_objs.extra_monitor_scp_messages\
 
 
 class ClearQueueProcess(AbstractMultiConnectionProcess):
-    def __init__(self, connection_selector):
-        super(ClearQueueProcess, self).__init__(connection_selector)
+    """ How to send messages to clear the reinjection queue.
+    """
 
     def reset_counters(self, core_subsets):
+        """
+        :param ~spinn_machine.CoreSubsets core_subsets:
+        """
         for core_subset in core_subsets.core_subsets:
             for processor_id in core_subset.processor_ids:
                 self._send_request(ClearReinjectionQueueMessage(
