@@ -13,11 +13,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import logging
 import math
 import struct
 import numpy
-from enum import Enum
-from six.moves import xrange
+from enum import IntEnum
+from spinn_utilities.log import FormatAdapter
 from spinn_utilities.overrides import overrides
 from spinnman.messages.eieio import EIEIOPrefix, EIEIOType
 from spinnman.messages.eieio.data_messages import EIEIODataHeader
@@ -30,6 +31,7 @@ from pacman.model.resources import (
     CPUCyclesPerTickResource, DTCMResource,
     ReverseIPtagResource, ResourceContainer, VariableSDRAM)
 from pacman.model.routing_info import BaseKeyAndMask
+from pacman.model.graphs.common import Slice
 from pacman.model.graphs.machine import MachineVertex
 from spinn_front_end_common.utilities.helpful_functions import (
     locate_memory_region_for_placement)
@@ -43,10 +45,11 @@ from spinn_front_end_common.interface.buffer_management.storage_objects \
     import (
         BufferedSendingRegion)
 from spinn_front_end_common.utilities.constants import (
-    SDP_PORTS, SYSTEM_BYTES_REQUIREMENT, SIMULATION_N_BYTES, BYTES_PER_WORD)
+    SDP_PORTS, SYSTEM_BYTES_REQUIREMENT, SIMULATION_N_BYTES, BYTES_PER_WORD,
+    MICRO_TO_MILLISECOND_CONVERSION)
 from spinn_front_end_common.utilities.exceptions import ConfigurationException
 from spinn_front_end_common.abstract_models import (
-    AbstractProvidesOutgoingPartitionConstraints, AbstractRecordable,
+    AbstractProvidesOutgoingPartitionConstraints,
     AbstractGeneratesDataSpecification, AbstractHasAssociatedBinary,
     AbstractSupportsDatabaseInjection)
 from spinn_front_end_common.interface.simulation.simulation_utilities import (
@@ -59,6 +62,8 @@ from spinn_front_end_common.interface.buffer_management.recording_utilities \
 from spinn_front_end_common.utilities.utility_objs import (
     ProvenanceDataItem, ExecutableType)
 
+logger = FormatAdapter(logging.getLogger(__name__))
+
 _DEFAULT_MALLOC_REGIONS = 2
 _ONE_WORD = struct.Struct("<I")
 _TWO_SHORTS = struct.Struct("<HH")
@@ -73,68 +78,68 @@ class ReverseIPTagMulticastSourceMachineVertex(
         AbstractHasAssociatedBinary, AbstractSupportsDatabaseInjection,
         ProvidesProvenanceDataFromMachineImpl,
         AbstractProvidesOutgoingPartitionConstraints,
-        SendsBuffersFromHostPreBufferedImpl,
-        AbstractReceiveBuffersToHost, AbstractRecordable):
+        SendsBuffersFromHostPreBufferedImpl, AbstractReceiveBuffersToHost):
     """ A model which allows events to be injected into SpiNNaker and\
-        converted in to multicast packets
+        converted in to multicast packets.
 
-    :param n_keys: The number of keys to be sent via this multicast source
-    :type n_keys: int
-    :param label: The label of this vertex
-    :type label: str
-    :param constraints: Any initial constraints to this vertex
-    :type constraints: \
-        iterable(~pacman.model.constraints.AbstractConstraint)
-    :param board_address: The IP address of the board on which to place\
-        this vertex if receiving data, either buffered or live (by\
-        default, any board is chosen)
-    :type board_address: str or None
-    :param receive_port: The port on the board that will listen for\
-        incoming event packets (default is to disable this feature; set a\
-        value to enable it)
-    :type receive_port: int or None
-    :param receive_sdp_port: The SDP port to listen on for incoming event\
-        packets (defaults to 1)
-    :type receive_sdp_port: int
-    :param receive_tag: The IP tag to use for receiving live events\
-        (uses any by default)
-    :type receive_tag: IPTag
-    :param receive_rate: The estimated rate of packets that will be sent\
-        by this source
-    :type receive_rate: float
-    :param virtual_key: The base multicast key to send received events\
-        with (assigned automatically by default)
-    :type virtual_key: int
-    :param prefix: The prefix to "or" with generated multicast keys\
-        (default is no prefix)
-    :type prefix: int
-    :param prefix_type: Whether the prefix should apply to the upper or\
-        lower half of the multicast keys (default is upper half)
-    :type prefix_type: ~spinnman.messages.eieio.EIEIOPrefix
-    :param check_keys: True if the keys of received events should be\
-        verified before sending (default False)
-    :type check_keys: bool
-    :param send_buffer_times: An array of arrays of times at which keys\
-        should be sent (one array for each key, default disabled)
-    :type send_buffer_times: \
-        numpy.ndarray(numpy.ndarray(numpy.int32)) or \
-        list(numpy.ndarray(numpy.int32)) or None
-    :param send_buffer_partition_id: The ID of the partition containing\
-        the edges down which the events are to be sent
-    :type send_buffer_partition_id: str or None
-    :param reserve_reverse_ip_tag: \
-        Extra flag for input without a reserved port
-    :type reserve_reverse_ip_tag: bool
+    :param str label: The label of this vertex
+    :param vertex_slice:
+        The slice served via this multicast source
+    :type vertex_slice: ~pacman.model.graphs.common.Slice or None
+    :param app_vertex:
+        The associated application vertex
+    :type app_vertex: ReverseIpTagMultiCastSource or None
+    :param int n_keys: The number of keys to be sent via this mulitcast source
+        (can't be None if vertex_slice is also None)
+    :param iterable(~pacman.model.constraints.AbstractConstraint) constraints:
+        Any initial constraints to this vertex
+    :param str board_address:
+        The IP address of the board on which to place this vertex if receiving
+        data, either buffered or live (by default, any board is chosen)
+    :param int receive_port:
+        The port on the board that will listen for incoming event packets
+        (default is to disable this feature; set a value to enable it, or set
+        the `reserve_reverse_ip_tag parameter` to True if a random port is to
+        be used)
+    :param int receive_sdp_port:
+        The SDP port to listen on for incoming event packets (defaults to 1)
+    :param int receive_tag:
+        The IP tag to use for receiving live events (uses any by default)
+    :param float receive_rate:
+    :param int virtual_key:
+        The base multicast key to send received events with (assigned
+        automatically by default)
+    :param int prefix:
+        The prefix to "or" with generated multicast keys (default is no prefix)
+    :param ~spinnman.messages.eieio.EIEIOPrefix prefix_type:
+        Whether the prefix should apply to the upper or lower half of the
+        multicast keys (default is upper half)
+    :param bool check_keys:
+        True if the keys of received events should be verified before sending
+        (default False)
+    :param ~numpy.ndarray send_buffer_times:
+        An array of arrays of time steps at which keys should be sent (one
+        array for each key, default disabled)
+    :param str send_buffer_partition_id:
+        The ID of the partition containing the edges down which the events are
+        to be sent
+    :param bool reserve_reverse_ip_tag:
+        True if the source should set up a tag through which it can receive
+        packets; if port is set to None this can be used to enable the
+        reception of packets on a randomly assigned port, which can be read
+        from the database
+    :param bool enable_injection:
+        Flag to indicate that data will be received to inject
     """
 
-    class _REGIONS(Enum):
+    class _REGIONS(IntEnum):
         SYSTEM = 0
         CONFIGURATION = 1
         RECORDING = 2
         SEND_BUFFER = 3
         PROVENANCE_REGION = 4
 
-    class _PROVENANCE_ITEMS(Enum):
+    class _PROVENANCE_ITEMS(IntEnum):
         N_RECEIVED_PACKETS = 0
         N_SENT_PACKETS = 1
         INCORRECT_KEYS = 2
@@ -153,7 +158,11 @@ class ReverseIPTagMulticastSourceMachineVertex(
     _n_data_specs = 0
 
     def __init__(
-            self, n_keys, label, constraints=None,
+            self, label,
+            vertex_slice=None,
+            app_vertex=None,
+            n_keys=None,
+            constraints=None,
 
             # General input and output parameters
             board_address=None,
@@ -173,13 +182,21 @@ class ReverseIPTagMulticastSourceMachineVertex(
             send_buffer_partition_id=None,
 
             # Extra flag for receiving packets without a port
-            reserve_reverse_ip_tag=False):
+            reserve_reverse_ip_tag=False,
+
+            # Flag to indicate that data will be received to inject
+            enable_injection=False):
         # pylint: disable=too-many-arguments, too-many-locals
-        super(ReverseIPTagMulticastSourceMachineVertex, self).__init__(
-            label, constraints)
+        if vertex_slice is None:
+            if n_keys is not None:
+                vertex_slice = Slice(0, n_keys - 1)
+            else:
+                raise KeyError("Either provide a vertex_slice or n_keys")
+
+        super().__init__(label, constraints, app_vertex, vertex_slice)
 
         self._reverse_iptags = None
-        self._n_keys = n_keys
+        self._n_keys = vertex_slice.n_atoms
 
         # Set up for receiving live packets
         if receive_port is not None or reserve_reverse_ip_tag:
@@ -203,6 +220,11 @@ class ReverseIPTagMulticastSourceMachineVertex(
                 else:
                     # assuming this must be a single integer
                     n_buffer_times += 1
+            if n_buffer_times == 0:
+                logger.warning(
+                    "Combination of send_buffer_times {} and slice {} results "
+                    "in a core with a ReverseIPTagMulticastSourceMachineVertex"
+                    " which does not spike", send_buffer_times, vertex_slice)
         if n_buffer_times == 0:
             self._send_buffer_times = None
             self._send_buffers = None
@@ -213,8 +235,9 @@ class ReverseIPTagMulticastSourceMachineVertex(
         self._is_recording = False
 
         # set flag for checking if in injection mode
-        self._in_injection_mode = \
-            receive_port is not None or reserve_reverse_ip_tag
+        self._in_injection_mode = (
+            receive_port is not None or reserve_reverse_ip_tag or
+            enable_injection)
 
         # Sort out the keys to be used
         self._virtual_key = virtual_key
@@ -232,12 +255,20 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
         # If the user has specified a virtual key
         if self._virtual_key is not None:
-            self._install_virtual_key(n_keys)
+            self._install_virtual_key(vertex_slice.n_atoms)
 
         self._n_vertices += 1
 
     @staticmethod
     def _max_send_buffer_keys_per_timestep(send_buffer_times, n_keys):
+        """
+        :param send_buffer_times: When events will be sent
+        :type send_buffer_times:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        :param int n_keys:
+        :rtype: int
+        """
         if len(send_buffer_times) and hasattr(send_buffer_times[0], "__len__"):
             counts = numpy.bincount(numpy.concatenate(send_buffer_times))
             if len(counts):
@@ -250,44 +281,61 @@ class ReverseIPTagMulticastSourceMachineVertex(
             return 0
         return 0
 
-    @staticmethod
-    def _send_buffer_sdram_per_timestep(send_buffer_times, n_keys):
+    @classmethod
+    def _send_buffer_sdram_per_timestep(cls, send_buffer_times, n_keys):
         """ Determine the amount of SDRAM required per timestep.
+
+        :param send_buffer_times:
+        :type send_buffer_times:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        :param int n_keys:
+        :rtype: int
         """
         # If there is a send buffer, calculate the keys per timestep
         if send_buffer_times is not None:
-            sdram = get_n_bytes(ReverseIPTagMulticastSourceMachineVertex
-                                ._max_send_buffer_keys_per_timestep(
-                                    send_buffer_times, n_keys))
-            return sdram
+            return get_n_bytes(cls._max_send_buffer_keys_per_timestep(
+                send_buffer_times, n_keys))
         return 0
 
-    @staticmethod
+    @classmethod
     def _recording_sdram_per_timestep(
-            machine_time_step, is_recording, receive_rate, send_buffer_times,
-            n_keys):
-
-        # If recording live data, use the user provided receive rate
-        if is_recording and send_buffer_times is None:
-            keys_per_timestep = math.ceil(
-                (receive_rate / (machine_time_step * 1000.0)) * 1.1
-            )
-            header_size = EIEIODataHeader.get_header_size(
-                EIEIOType.KEY_32_BIT, is_payload_base=True)
-            # Maximum size is one packet per key
-            return ((header_size + EIEIOType.KEY_32_BIT.key_bytes) *
-                    keys_per_timestep)
+            cls, machine_time_step, is_recording, receive_rate,
+            send_buffer_times, n_keys):
+        """
+        :param int machine_time_step:
+        :param bool is_recording:
+        :param float receive_rate:
+        :param send_buffer_times:
+        :type send_buffer_times:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        :param int n_keys:
+        :rtype: int
+        """
+        # If not recording, no SDRAM needed per timestep
+        if not is_recording:
+            return 0
 
         # If recording send data, the recorded size is the send size
-        if is_recording and send_buffer_times is not None:
-            return (ReverseIPTagMulticastSourceMachineVertex
-                    ._send_buffer_sdram_per_timestep(
-                        send_buffer_times, n_keys))
+        if send_buffer_times is not None:
+            return cls._send_buffer_sdram_per_timestep(
+                send_buffer_times, n_keys)
 
-        # Not recording no SDRAM needed per timestep
-        return 0
+        # Recording live data, use the user provided receive rate
+        keys_per_timestep = math.ceil(
+            receive_rate / (
+                machine_time_step * MICRO_TO_MILLISECOND_CONVERSION) * 1.1)
+        header_size = EIEIODataHeader.get_header_size(
+            EIEIOType.KEY_32_BIT, is_payload_base=True)
+        # Maximum size is one packet per key
+        return ((header_size + EIEIOType.KEY_32_BIT.key_bytes) *
+                keys_per_timestep)
 
     def _install_send_buffer(self, send_buffer_times):
+        """
+        :param ~numpy.ndarray send_buffer_times:
+        """
         if len(send_buffer_times) and hasattr(send_buffer_times[0], "__len__"):
             # Working with a list of lists so check length
             if len(send_buffer_times) != self._n_keys:
@@ -299,10 +347,13 @@ class ReverseIPTagMulticastSourceMachineVertex(
         self._send_buffer = BufferedSendingRegion()
         self._send_buffer_times = send_buffer_times
         self._send_buffers = {
-            self._REGIONS.SEND_BUFFER.value: self._send_buffer
+            self._REGIONS.SEND_BUFFER: self._send_buffer
         }
 
     def _install_virtual_key(self, n_keys):
+        """
+        :param int n_keys:
+        """
         # check that virtual key is valid
         if self._virtual_key < 0:
             raise ConfigurationException("Virtual keys must be positive")
@@ -327,7 +378,7 @@ class ReverseIPTagMulticastSourceMachineVertex(
     @property
     @overrides(ProvidesProvenanceDataFromMachineImpl._provenance_region_id)
     def _provenance_region_id(self):
-        return self._REGIONS.PROVENANCE_REGION.value
+        return self._REGIONS.PROVENANCE_REGION
 
     @property
     @overrides(ProvidesProvenanceDataFromMachineImpl._n_additional_data_items)
@@ -339,8 +390,8 @@ class ReverseIPTagMulticastSourceMachineVertex(
     def resources_required(self):
         sim = globals_variables.get_simulator()
         sdram = self.get_sdram_usage(
-                self._send_buffer_times, self._is_recording,
-                sim.machine_time_step, self._receive_rate, self._n_keys)
+            self._send_buffer_times, self._is_recording,
+            sim.machine_time_step, self._receive_rate, self._n_keys)
 
         resources = ResourceContainer(
             dtcm=DTCMResource(self.get_dtcm_usage()),
@@ -349,38 +400,30 @@ class ReverseIPTagMulticastSourceMachineVertex(
             reverse_iptags=self._reverse_iptags)
         return resources
 
-    @staticmethod
+    @classmethod
     def get_sdram_usage(
-            send_buffer_times, recording_enabled, machine_time_step,
+            cls, send_buffer_times, recording_enabled, machine_time_step,
             receive_rate, n_keys):
         """
         :param send_buffer_times: When events will be sent
-        :type send_buffer_times: \
-            numpy.ndarray(numpy.ndarray(numpy.int32)) or \
-            list(numpy.ndarray(numpy.int32)) or None
-        :param recording_enabled: Whether recording is done
-        :type recording_enabled: bool
-        :param machine_time_step: What the machine timestep is
-        :type machine_time_step: int
-        :param receive_rate: What the expected message receive rate is
-        :type receive_rate: float
-        :param n_keys: How many keys are being sent
-        :type n_keys: int
+        :type send_buffer_times:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        :param bool recording_enabled: Whether recording is done
+        :param int machine_time_step: What the machine timestep is
+        :param float receive_rate: What the expected message receive rate is
+        :param int n_keys: How many keys are being sent
+        :rtype: ~pacman.model.resources.VariableSDRAM
         """
-
         static_usage = (
             SYSTEM_BYTES_REQUIREMENT +
-            (ReverseIPTagMulticastSourceMachineVertex.
-                _CONFIGURATION_REGION_SIZE) +
+            cls._CONFIGURATION_REGION_SIZE +
             get_recording_header_size(1) +
             get_recording_data_constant_size(1) +
-            (ReverseIPTagMulticastSourceMachineVertex.
-                get_provenance_data_size(0)))
+            cls.get_provenance_data_size(0))
         per_timestep = (
-            ReverseIPTagMulticastSourceMachineVertex
-            ._send_buffer_sdram_per_timestep(send_buffer_times, n_keys) +
-            ReverseIPTagMulticastSourceMachineVertex.
-            _recording_sdram_per_timestep(
+            cls._send_buffer_sdram_per_timestep(send_buffer_times, n_keys) +
+            cls._recording_sdram_per_timestep(
                 machine_time_step, recording_enabled, receive_rate,
                 send_buffer_times, n_keys))
         static_usage += per_timestep
@@ -397,6 +440,10 @@ class ReverseIPTagMulticastSourceMachineVertex(
     @staticmethod
     def _n_regions_to_allocate(send_buffering, recording):
         """ Get the number of regions that will be allocated
+
+        :param bool send_buffering:
+        :param bool recording:
+        :rtype: int
         """
         if recording and send_buffering:
             return 5
@@ -406,24 +453,44 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
     @property
     def send_buffer_times(self):
+        """ When events will be sent.
+
+        :rtype:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        """
         return self._send_buffer_times
 
     @send_buffer_times.setter
     def send_buffer_times(self, send_buffer_times):
+        """
+        :type send_buffer_times:
+            ~numpy.ndarray(~numpy.ndarray(numpy.int32)) or
+            list(~numpy.ndarray(numpy.int32)) or None
+        """
         self._install_send_buffer(send_buffer_times)
 
+    @staticmethod
     def _is_in_range(
-            self, time_stamp_in_ticks,
+            time_stamp_in_ticks,
             first_machine_time_step, n_machine_time_steps):
+        """
+        :param int time_stamp_in_ticks:
+        :param int first_machine_time_step:
+        :param n_machine_time_steps:
+        :type n_machine_time_steps: int or None
+        """
         return (n_machine_time_steps is None) or (
             first_machine_time_step <= time_stamp_in_ticks <
             n_machine_time_steps)
 
     def _fill_send_buffer(
             self, first_machine_time_step, run_until_timesteps):
-        """ Fill the send buffer with keys to send
-        """
+        """ Fill the send buffer with keys to send.
 
+        :param int first_machine_time_step:
+        :param int run_until_timesteps:
+        """
         key_to_send = self._virtual_key
         if self._virtual_key is None:
             key_to_send = 0
@@ -443,6 +510,11 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
     def __fill_send_buffer_2d(
             self, key_base, first_time_step, n_time_steps):
+        """
+        :param int key_base:
+        :param int first_time_step:
+        :param int n_time_steps:
+        """
         for key in range(self._n_keys):
             for tick in sorted(self._send_buffer_times[key]):
                 if self._is_in_range(tick, first_time_step, n_time_steps):
@@ -450,41 +522,61 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
     def __fill_send_buffer_1d(
             self, key_base, first_time_step, n_time_steps):
-        key_list = [key + key_base for key in xrange(self._n_keys)]
+        """
+        :param int key_base:
+        :param int first_time_step:
+        :param int n_time_steps:
+        """
+        key_list = [key + key_base for key in range(self._n_keys)]
         for tick in sorted(self._send_buffer_times):
             if self._is_in_range(tick, first_time_step, n_time_steps):
                 self._send_buffer.add_keys(tick, key_list)
 
     @staticmethod
     def _generate_prefix(virtual_key, prefix_type):
+        """
+        :param ~.EIEIOPrefix prefix_type:
+        :param int virtual_key:
+        :rtype: int
+        """
         if prefix_type == EIEIOPrefix.LOWER_HALF_WORD:
             return virtual_key & 0xFFFF
         return (virtual_key >> 16) & 0xFFFF
 
     @staticmethod
     def _calculate_mask(n_neurons):
+        """
+        :param int n_neurons:
+        :rtype: int
+        """
         temp_value = n_neurons.bit_length()
         max_key = 2**temp_value - 1
         mask = 0xFFFFFFFF - max_key
         return mask
 
     def enable_recording(self, new_state=True):
-        """ Enable recording of the keys sent
+        """ Enable recording of the keys sent.
+
+        :param bool new_state:
         """
         self._is_recording = new_state
 
     def _reserve_regions(self, spec, n_machine_time_steps):
+        """
+        :param ~.DataSpecificationGenerator spec:
+        :param int n_machine_time_steps:
+        """
         # Reserve system and configuration memory regions:
         spec.reserve_memory_region(
-            region=self._REGIONS.SYSTEM.value,
+            region=self._REGIONS.SYSTEM,
             size=SIMULATION_N_BYTES, label='SYSTEM')
         spec.reserve_memory_region(
-            region=self._REGIONS.CONFIGURATION.value,
+            region=self._REGIONS.CONFIGURATION,
             size=self._CONFIGURATION_REGION_SIZE, label='CONFIGURATION')
 
         # Reserve recording buffer regions if required
         spec.reserve_memory_region(
-            region=self._REGIONS.RECORDING.value,
+            region=self._REGIONS.RECORDING,
             size=get_recording_header_size(1),
             label="RECORDING")
 
@@ -496,16 +588,19 @@ class ReverseIPTagMulticastSourceMachineVertex(
                 n_machine_time_steps)
             if self._send_buffer_size:
                 spec.reserve_memory_region(
-                    region=self._REGIONS.SEND_BUFFER.value,
+                    region=self._REGIONS.SEND_BUFFER,
                     size=self._send_buffer_size, label="SEND_BUFFER",
                     empty=True)
 
         self.reserve_provenance_data_region(spec)
 
     def _update_virtual_key(self, routing_info, machine_graph):
+        """
+        :param ~pacman.model.routing_info.RoutingInfo routing_info:
+        :param ~pacman.model.graphs.machine.MachineGraph machine_graph:
+        """
         if self._virtual_key is None:
             if self._send_buffer_partition_id is not None:
-
                 rinfo = routing_info.get_routing_info_from_pre_vertex(
                     self, self._send_buffer_partition_id)
 
@@ -513,10 +608,9 @@ class ReverseIPTagMulticastSourceMachineVertex(
                 if rinfo is not None:
                     self._virtual_key = rinfo.first_key
                     self._mask = rinfo.first_mask
-
             else:
                 partitions = machine_graph\
-                    .get_outgoing_edge_partitions_starting_at_vertex(self)
+                    .get_multicast_edge_partitions_starting_at_vertex(self)
                 partition = next(iter(partitions), None)
 
                 if partition is not None:
@@ -529,9 +623,14 @@ class ReverseIPTagMulticastSourceMachineVertex(
             self._prefix_type = EIEIOPrefix.UPPER_HALF_WORD
             self._prefix = self._virtual_key
 
-    def _write_configuration(self, spec, machine_time_step,
-                             time_scale_factor):
-        spec.switch_write_focus(region=self._REGIONS.CONFIGURATION.value)
+    def _write_configuration(
+            self, spec, machine_time_step, time_scale_factor):
+        """
+        :param ~.DataSpecificationGenerator spec:
+        :param int machine_time_step:
+        :param int time_scale_factor:
+        """
+        spec.switch_write_focus(region=self._REGIONS.CONFIGURATION)
 
         # Write apply_prefix and prefix and prefix_type
         if self._prefix is None:
@@ -578,11 +677,14 @@ class ReverseIPTagMulticastSourceMachineVertex(
         spec.write_value(data=self._receive_sdp_port)
 
         # write timer offset in microseconds
-        max_offset = (
-            machine_time_step * time_scale_factor) // _MAX_OFFSET_DENOMINATOR
+        max_offset = ((
+            machine_time_step * time_scale_factor) // (
+            _MAX_OFFSET_DENOMINATOR * 2))
         spec.write_value(
-            int(math.ceil(max_offset / self._n_vertices)) * self._n_data_specs)
-        self._n_data_specs += 1
+            (int(math.ceil(max_offset / self._n_vertices)) *
+             ReverseIPTagMulticastSourceMachineVertex._n_data_specs) +
+            int(math.ceil(max_offset)))
+        ReverseIPTagMulticastSourceMachineVertex._n_data_specs += 1
 
     @inject_items({
         "machine_time_step": "MachineTimeStep",
@@ -604,6 +706,15 @@ class ReverseIPTagMulticastSourceMachineVertex(
             self, spec, placement,  # @UnusedVariable
             machine_time_step, time_scale_factor, machine_graph, routing_info,
             first_machine_time_step, data_n_time_steps, run_until_timesteps):
+        """
+        :param int machine_time_step:
+        :param int time_scale_factor:
+        :param ~pacman.model.graphs.machine.MachineGraph machine_graph:
+        :param ~pacman.model.routing_info.RoutingInfo routing_info:
+        :param int first_machine_time_step:
+        :param int data_n_time_steps:
+        :param int run_until_timesteps:
+        """
         # pylint: disable=too-many-arguments, arguments-differ
         self._update_virtual_key(routing_info, machine_graph)
         self._fill_send_buffer(first_machine_time_step, run_until_timesteps)
@@ -612,13 +723,13 @@ class ReverseIPTagMulticastSourceMachineVertex(
         self._reserve_regions(spec, data_n_time_steps)
 
         # Write the system region
-        spec.switch_write_focus(self._REGIONS.SYSTEM.value)
+        spec.switch_write_focus(self._REGIONS.SYSTEM)
         spec.write_array(get_simulation_header_array(
             self.get_binary_file_name(), machine_time_step,
             time_scale_factor))
 
         # Write the additional recording information
-        spec.switch_write_focus(self._REGIONS.RECORDING.value)
+        spec.switch_write_focus(self._REGIONS.RECORDING)
         recording_size = 0
         if self._is_recording:
             per_timestep = self._recording_sdram_per_timestep(
@@ -652,10 +763,16 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
     @property
     def virtual_key(self):
+        """
+        :rtype: int or None
+        """
         return self._virtual_key
 
     @property
     def mask(self):
+        """
+        :rtype: int or None
+        """
         return self._mask
 
     @property
@@ -663,10 +780,6 @@ class ReverseIPTagMulticastSourceMachineVertex(
     def is_in_injection_mode(self):
         return self._in_injection_mode
 
-    @overrides(AbstractRecordable.is_recording)
-    def is_recording(self):
-        return self._is_recording > 0
-
     @inject("FirstMachineTimeStep")
     @inject_items({
         "run_until_timesteps": "RunUntilTimeSteps"
@@ -676,12 +789,10 @@ class ReverseIPTagMulticastSourceMachineVertex(
         """ Updates the buffers on specification of the first machine timestep.
             Note: This is called by injection.
 
-        :param first_machine_time_step:\
+        :param int first_machine_time_step:
             The first machine time step in the simulation
-        :type first_machine_time_step: int
-        :param run_until_timesteps:\
+        :param int run_until_timesteps:
             The last machine time step in the simulation
-        :type run_until_timesteps: int
         """
         if self._virtual_key is not None:
             self._fill_send_buffer(
@@ -696,15 +807,26 @@ class ReverseIPTagMulticastSourceMachineVertex(
     @overrides(AbstractReceiveBuffersToHost.get_recording_region_base_address)
     def get_recording_region_base_address(self, txrx, placement):
         return locate_memory_region_for_placement(
-            placement, self._REGIONS.RECORDING.value, txrx)
+            placement, self._REGIONS.RECORDING, txrx)
 
     @property
-    @overrides(SendsBuffersFromHostPreBufferedImpl.send_buffers)
     def send_buffers(self):
+        """
+        :rtype: dict(int,BufferedSendingRegion)
+        """
         return self._send_buffers
 
+    @send_buffers.setter
+    def send_buffers(self, value):
+        self._send_buffers = value
+
     def get_region_buffer_size(self, region):
-        if region == self._REGIONS.SEND_BUFFER.value:
+        """
+        :param int region: Region ID
+        :return: Size of buffer, in bytes.
+        :rtype: int
+        """
+        if region == self._REGIONS.SEND_BUFFER:
             return self._send_buffer_size
         return 0
 
@@ -720,10 +842,10 @@ class ReverseIPTagMulticastSourceMachineVertex(
 
         provenance_items.append(ProvenanceDataItem(
             self._add_name(names, "received_sdp_packets"),
-            provenance_data[self._PROVENANCE_ITEMS.N_RECEIVED_PACKETS.value],
+            provenance_data[self._PROVENANCE_ITEMS.N_RECEIVED_PACKETS],
             report=(
                 provenance_data[
-                    self._PROVENANCE_ITEMS.N_RECEIVED_PACKETS.value] == 0 and
+                    self._PROVENANCE_ITEMS.N_RECEIVED_PACKETS] == 0 and
                 self._send_buffer_times is None),
             message=(
                 "No SDP packets were received by {}.  If you expected packets"
@@ -731,35 +853,32 @@ class ReverseIPTagMulticastSourceMachineVertex(
                     self._label))))
         provenance_items.append(ProvenanceDataItem(
             self._add_name(names, "send_multicast_packets"),
-            provenance_data[self._PROVENANCE_ITEMS.N_SENT_PACKETS.value],
-            report=provenance_data[
-                self._PROVENANCE_ITEMS.N_SENT_PACKETS.value] == 0,
+            provenance_data[self._PROVENANCE_ITEMS.N_SENT_PACKETS],
+            report=provenance_data[self._PROVENANCE_ITEMS.N_SENT_PACKETS] == 0,
             message=(
                 "No multicast packets were sent by {}.  If you expected"
                 " packets to be sent this could indicate an error".format(
                     self._label))))
         provenance_items.append(ProvenanceDataItem(
             self._add_name(names, "incorrect_keys"),
-            provenance_data[self._PROVENANCE_ITEMS.INCORRECT_KEYS.value],
-            report=provenance_data[
-                self._PROVENANCE_ITEMS.INCORRECT_KEYS.value] > 0,
+            provenance_data[self._PROVENANCE_ITEMS.INCORRECT_KEYS],
+            report=provenance_data[self._PROVENANCE_ITEMS.INCORRECT_KEYS] > 0,
             message=(
                 "Keys were received by {} that did not match the key {} and"
                 " mask {}".format(
                     self._label, self._virtual_key, self._mask))))
         provenance_items.append(ProvenanceDataItem(
             self._add_name(names, "incorrect_packets"),
-            provenance_data[self._PROVENANCE_ITEMS.INCORRECT_PACKETS.value],
+            provenance_data[self._PROVENANCE_ITEMS.INCORRECT_PACKETS],
             report=provenance_data[
-                self._PROVENANCE_ITEMS.INCORRECT_PACKETS.value] > 0,
+                self._PROVENANCE_ITEMS.INCORRECT_PACKETS] > 0,
             message=(
                 "SDP Packets were received by {} that were not correct".format(
                     self._label))))
         provenance_items.append(ProvenanceDataItem(
             self._add_name(names, "late_packets"),
-            provenance_data[self._PROVENANCE_ITEMS.LATE_PACKETS.value],
-            report=provenance_data[
-                self._PROVENANCE_ITEMS.LATE_PACKETS.value] > 0,
+            provenance_data[self._PROVENANCE_ITEMS.LATE_PACKETS],
+            report=provenance_data[self._PROVENANCE_ITEMS.LATE_PACKETS] > 0,
             message=(
                 "SDP Packets were received by {} that were too late to be"
                 " transmitted in the simulation".format(self._label))))
